@@ -1,8 +1,8 @@
 /* Eye Of Gnome - Image Store
  *
- * Copyright (C) 2006-2007 The Free Software Foundation
+ * Copyright (C) 2006-2008 The Free Software Foundation
  *
- * Author: Claudio Saavedra <csaavedra@alumnos.utalca.cl>
+ * Author: Claudio Saavedra <csaavedra@gnome.org>
  *
  * Based on code by: Jens Finke <jens@triq.net>
  *
@@ -34,17 +34,6 @@
 
 G_DEFINE_TYPE (EogListStore, eog_list_store, GTK_TYPE_LIST_STORE);
 
-typedef struct {
-	EogListStore *store;
-	GnomeVFSURI *uri;
-	GnomeVFSFileInfo *info;
-} DirLoadingContext;
-
-typedef struct {
-	GnomeVFSMonitorHandle *handle;
-	const gchar *text_uri;
-} MonitorHandleContext;
-
 struct _EogListStorePrivate {
 	GList *monitors;          /* Monitors for the directories */
 	gint initial_image;       /* The image that should be selected firstly by the view. */
@@ -68,12 +57,8 @@ eog_list_store_finalize (GObject *object)
 
 static void
 foreach_monitors_free (gpointer data, gpointer user_data)
-{
-	MonitorHandleContext *hctx = data;
-	
-	gnome_vfs_monitor_cancel (hctx->handle);
-	
-	g_free (data);
+{	
+	g_file_monitor_cancel (G_FILE_MONITOR (data));
 }
 
 static void
@@ -200,13 +185,20 @@ eog_list_store_init (EogListStore *self)
 					      GTK_SORT_ASCENDING);
 }
 
+/**
+ * eog_list_store_new:
+ *
+ * Creates a new and empty #EogListStore.
+ *
+ * Returns: a newly created #EogListStore.
+ **/
 GtkListStore*
 eog_list_store_new (void)
 {
         return g_object_new (EOG_TYPE_LIST_STORE, NULL);
 }
 
-/**
+/*
    Searchs for a file in the store. If found and @iter_found is not NULL,
    then sets @iter_found to a #GtkTreeIter pointing to the file.
  */
@@ -217,7 +209,7 @@ is_file_in_list_store (EogListStore *store,
 {
 	gboolean found = FALSE;
 	EogImage *image;
-	GnomeVFSURI *uri;
+	GFile *file;
 	gchar *str;
 	GtkTreeIter iter;
 
@@ -232,12 +224,12 @@ is_file_in_list_store (EogListStore *store,
 		if (!image)
 			continue;
 		
-		uri = eog_image_get_uri (image);
-		str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+		file = eog_image_get_file (image);
+		str = g_file_get_uri (file);
 		
 		found = (strcmp (str, info_uri) == 0)? TRUE : FALSE;
 		
-		gnome_vfs_uri_unref (uri);
+		g_object_unref (file);
 		g_free (str);
 		g_object_unref (G_OBJECT (image));
 
@@ -252,14 +244,14 @@ is_file_in_list_store (EogListStore *store,
 }
 
 static gboolean
-is_file_in_list_store_uri (EogListStore *store,
-			   const GnomeVFSURI *uri,
+is_file_in_list_store_file (EogListStore *store,
+			   GFile *file,
 			   GtkTreeIter *iter_found)
 {
 	gchar *uri_str;
 	gboolean result;
 	
-	uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+	uri_str = g_file_get_uri (file);
 
 	result = is_file_in_list_store (store, uri_str, iter_found);
 
@@ -275,15 +267,15 @@ eog_job_thumbnail_cb (EogJobThumbnail *job, gpointer data)
 	GtkTreeIter iter;
 	EogImage *image;
 	GdkPixbuf *thumbnail;
-	GnomeVFSURI *uri;
+	GFile *file;
 
 	g_return_if_fail (EOG_IS_LIST_STORE (data));
 
 	store = EOG_LIST_STORE (data);
 
-	uri = eog_image_get_uri (job->image);
+	file = eog_image_get_file (job->image);
 
-	if (is_file_in_list_store_uri (store, uri, &iter)) {
+	if (is_file_in_list_store_file (store, file, &iter)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 
 				    EOG_LIST_STORE_EOG_IMAGE, &image,
 				    -1);
@@ -307,7 +299,7 @@ eog_job_thumbnail_cb (EogJobThumbnail *job, gpointer data)
 		g_object_unref (thumbnail);
 	}
 
-	gnome_vfs_uri_unref (uri);
+	g_object_unref (file);
 }
 
 static void
@@ -325,6 +317,13 @@ on_image_changed (EogImage *image, EogListStore *store)
 	gtk_tree_path_free (path);
 }
 
+/**
+ * eog_list_store_remove:
+ * @store: An #EogListStore.
+ * @iter: A #GtkTreeIter.
+ *
+ * Removes the image pointed by @iter from @store.
+ **/
 static void
 eog_list_store_remove (EogListStore *store, GtkTreeIter *iter)
 {
@@ -340,6 +339,16 @@ eog_list_store_remove (EogListStore *store, GtkTreeIter *iter)
 	gtk_list_store_remove (GTK_LIST_STORE (store), iter);
 }
 
+/**
+ * eog_list_store_append_image:
+ * @store: An #EogListStore.
+ * @image: An #EogImage.
+ *
+ * Adds an #EogImage to @store. The thumbnail of the image is not
+ * loaded and will only be loaded if the thumbnail is made visible
+ * or eog_list_store_set_thumbnail() is called.
+ *
+ **/
 void
 eog_list_store_append_image (EogListStore *store, EogImage *image)
 {
@@ -358,38 +367,40 @@ eog_list_store_append_image (EogListStore *store, EogImage *image)
 }
 
 static void 
-eog_list_store_append_image_from_uri (EogListStore *store, 
-				      GnomeVFSURI *uri_entry,
-				      gboolean is_monitored)
+eog_list_store_append_image_from_file (EogListStore *store, 
+				       GFile *file)
 {
 	EogImage *image;
 	
 	g_return_if_fail (EOG_IS_LIST_STORE (store));
 
-	image = eog_image_new_uri (uri_entry);
-
-	eog_image_set_is_monitored (image, is_monitored);
+	image = eog_image_new_file (file);
 
 	eog_list_store_append_image (store, image);
 }
 
 static void
-vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
-		    const gchar *monitor_uri,
-		    const gchar *info_uri,
-		    GnomeVFSMonitorEventType event_type,
-		    gpointer user_data)
+file_monitor_changed_cb (GFileMonitor *monitor,
+			 GFile *file,
+			 GFile *other_file,
+			 GFileMonitorEvent event,
+			 EogListStore *store)
 {
-	EogListStore *store = EOG_LIST_STORE (user_data);
-	GnomeVFSURI *uri = NULL;
+	const char *mimetype;
+	GFileInfo *file_info;
 	GtkTreeIter iter;
-	gchar *mimetype;
 
-	switch (event_type) {
-	case GNOME_VFS_MONITOR_EVENT_CHANGED:
-		mimetype = gnome_vfs_get_mime_type (info_uri);
-
-		if (is_file_in_list_store (store, info_uri, &iter)) {
+	switch (event) {
+	case G_FILE_MONITOR_EVENT_CHANGED:		
+		file_info = g_file_query_info (file,
+					       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+					       0, NULL, NULL);
+		if (file_info == NULL) {
+			break;
+		}
+		mimetype = g_file_info_get_content_type (file_info);
+	
+		if (is_file_in_list_store_file (store, file, &iter)) {
 			if (eog_image_is_supported_mime_type (mimetype)) {
 				eog_list_store_thumbnail_refresh (store, &iter);
 			} else {
@@ -397,54 +408,55 @@ vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
 			}
 		} else {
 			if (eog_image_is_supported_mime_type (mimetype)) {
-				uri = gnome_vfs_uri_new (info_uri);
-				eog_list_store_append_image_from_uri (store, uri, TRUE);
-				gnome_vfs_uri_unref (uri);
+				eog_list_store_append_image_from_file (store, file);
 			}
 		}
-
-		g_free (mimetype);
+		g_object_unref (file_info);
 		break;
-
-	case GNOME_VFS_MONITOR_EVENT_DELETED:
-		if (is_file_in_list_store (store, info_uri, &iter)) {
+	case G_FILE_MONITOR_EVENT_DELETED:
+		if (is_file_in_list_store_file (store, file, &iter)) {
 			EogImage *image;
 
 			gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
 					    EOG_LIST_STORE_EOG_IMAGE, &image,
 					    -1);
 
-			if (eog_image_get_status (image) != EOG_IMAGE_STATUS_SAVING) {
-				eog_list_store_remove (store, &iter);
-			} else {
-				eog_image_restore_status (image);
-			}
+			eog_list_store_remove (store, &iter);
 		}
 		break;
+	case G_FILE_MONITOR_EVENT_CREATED:
+		if (!is_file_in_list_store_file (store, file, NULL)) {
+			file_info = g_file_query_info (file,
+						       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+						       0, NULL, NULL);
+			if (file_info == NULL) {
+				break;
+			}
+			mimetype = g_file_info_get_content_type (file_info);
 
-	case GNOME_VFS_MONITOR_EVENT_CREATED:
-		if (!is_file_in_list_store (store, info_uri, NULL)) {
-			mimetype = gnome_vfs_get_mime_type (info_uri);
 			if (eog_image_is_supported_mime_type (mimetype)) {
-				uri = gnome_vfs_uri_new (info_uri);
-				eog_list_store_append_image_from_uri (store, uri, TRUE);
-				gnome_vfs_uri_unref (uri);
+				eog_list_store_append_image_from_file (store, file);
 			}
-			g_free (mimetype);
+			g_object_unref (file_info);
 		}
 		break;
-
-	case GNOME_VFS_MONITOR_EVENT_METADATA_CHANGED:
-		mimetype = gnome_vfs_get_mime_type (info_uri);
-		if (is_file_in_list_store (store, info_uri, &iter) &&
+	case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED:
+		file_info = g_file_query_info (file,
+					       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+					       0, NULL, NULL);
+		if (file_info == NULL) {
+			break;
+		}
+		mimetype = g_file_info_get_content_type (file_info);
+		if (is_file_in_list_store_file (store, file, &iter) &&
 		    eog_image_is_supported_mime_type (mimetype)) {
 			eog_list_store_thumbnail_refresh (store, &iter);
 		}
-		g_free (mimetype);
+		g_object_unref (file_info);
 		break;
-
-	case GNOME_VFS_MONITOR_EVENT_STARTEXECUTING:
-	case GNOME_VFS_MONITOR_EVENT_STOPEXECUTING:
+	case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
+	case G_FILE_MONITOR_EVENT_PRE_UNMOUNT:
+	case G_FILE_MONITOR_EVENT_UNMOUNTED:
 		break;
 	}
 }
@@ -454,176 +466,189 @@ vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
  * sort of image. If so, it creates an image object and adds it to the
  * list.
  */
-static gboolean
-directory_visit_cb (const gchar *rel_uri,
-		    GnomeVFSFileInfo *info,
-		    gboolean recursing_will_loop,
-		    gpointer data,
-		    gboolean *recurse)
+static void
+directory_visit (GFile *directory,
+		 GFileInfo *children_info,
+		 EogListStore *store)
 {
-	GnomeVFSURI *uri;
-	EogListStore *store;
+	GFile *child;
 	gboolean load_uri = FALSE;
-	DirLoadingContext *ctx;
+	const char *mime_type, *name;
 	
-	ctx = (DirLoadingContext*) data;
-	store = ctx->store;
+	mime_type = g_file_info_get_content_type (children_info);
+	name = g_file_info_get_name (children_info);
 	
-        if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) > 0 &&
-            !g_str_has_prefix (info->name, ".")) {
-		if (eog_image_is_supported_mime_type (info->mime_type)) {
+        if (!g_str_has_prefix (name, ".")) {
+		if (eog_image_is_supported_mime_type (mime_type)) {
 			load_uri = TRUE;
 		}
 	}
 
 	if (load_uri) {
-		uri = gnome_vfs_uri_append_file_name (ctx->uri, rel_uri);
-		eog_list_store_append_image_from_uri (store, uri, TRUE);
+		child = g_file_get_child (directory, name);
+		eog_list_store_append_image_from_file (store, child);
 	}
-
-	return TRUE;
 }
 
 static void 
 eog_list_store_append_directory (EogListStore *store, 
-				 GnomeVFSURI *uri, 
-				 GnomeVFSFileInfo *info)
+				 GFile *file, 
+				 GFileType file_type)
 {
-	DirLoadingContext ctx;
-	MonitorHandleContext *hctx = g_new0(MonitorHandleContext, 1);
-
-	hctx->text_uri = gnome_vfs_uri_get_path (uri);
+	GFileMonitor *file_monitor;
+	GFileEnumerator *file_enumerator;
+	GFileInfo *file_info;
 	
-	g_return_if_fail (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY);
-
-	ctx.uri = uri;
-	ctx.store = store;
-	ctx.info = info;
+	g_return_if_fail (file_type == G_FILE_TYPE_DIRECTORY);
 	
-	gnome_vfs_monitor_add  (&hctx->handle, hctx->text_uri,
-				GNOME_VFS_MONITOR_DIRECTORY,
-				vfs_monitor_dir_cb,
-				store);
+	file_monitor = g_file_monitor_directory (file,
+						 0, NULL, NULL);
 
-	/* prepend seems more efficient to me, we don't need this list
-	   to be sorted */
-	store->priv->monitors = g_list_prepend (store->priv->monitors, hctx);
-	
-	/* Forcing slow MIME type checking, so we don't need to make 
-	   workarounds for files with strange extensions (#333551) */
-	gnome_vfs_directory_visit_uri (uri,
-				       GNOME_VFS_FILE_INFO_DEFAULT |
-				       GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
-				       GNOME_VFS_FILE_INFO_GET_MIME_TYPE | 
-				       GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE,
-				       GNOME_VFS_DIRECTORY_VISIT_DEFAULT,
-				       directory_visit_cb,
-				       &ctx);
-}
+	if (file_monitor != NULL) {
+		g_signal_connect (file_monitor, "changed",
+				  G_CALLBACK (file_monitor_changed_cb), store);
 
-static gboolean
-get_uri_info (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
-{
-	GnomeVFSResult result;
-	
-	g_return_val_if_fail (uri != NULL, FALSE);
-	g_return_val_if_fail (info != NULL, FALSE);
-	
-	gnome_vfs_file_info_clear (info);
+		/* prepend seems more efficient to me, we don't need this list
+		   to be sorted */
+		store->priv->monitors = g_list_prepend (store->priv->monitors, file_monitor);
+	}
 
-	result = gnome_vfs_get_file_info_uri (uri, info,
-					      GNOME_VFS_FILE_INFO_DEFAULT |
-					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
-					      GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
-	
-	return (result == GNOME_VFS_OK);
+	file_enumerator = g_file_enumerate_children (file,
+						     G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+						     G_FILE_ATTRIBUTE_STANDARD_NAME,
+						     0, NULL, NULL);
+	file_info = g_file_enumerator_next_file (file_enumerator, NULL, NULL);
+
+	while (file_info != NULL)
+	{
+		directory_visit (file, file_info, store);
+		g_object_unref (file_info);
+		file_info = g_file_enumerator_next_file (file_enumerator, NULL, NULL);
+	}
+	g_object_unref (file_enumerator);
 }
 
+/**
+ * eog_list_store_add_files:
+ * @store: An #EogListStore.
+ * @file_list: A %NULL-terminated list of #GFile's.
+ *
+ * Adds a list of #GFile's to @store. The given list
+ * must be %NULL-terminated.
+ *
+ * If any of the #GFile's in @file_list is a directory, all the images
+ * in that directory will be added to @store. If the list of files contains
+ * only one file and this is a regular file, then all the images in the same
+ * directory will be added as well to @store.
+ *
+ **/
 void
-eog_list_store_add_uris (EogListStore *store, GList *uri_list) 
+eog_list_store_add_files (EogListStore *store, GList *file_list) 
 {
 	GList *it;
-	GnomeVFSFileInfo *info;
-	GnomeVFSURI *initial_uri = NULL;
+	GFileInfo *file_info;
+	GFileType file_type;
+	GFile *initial_file = NULL;
 	GtkTreeIter iter;
 
-	if (uri_list == NULL) {
+	if (file_list == NULL) {
 		return;
 	}
-	
-	info = gnome_vfs_file_info_new ();
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
 					      GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID,
 					      GTK_SORT_ASCENDING);
 	
-	for (it = uri_list; it != NULL; it = it->next) {
-		GnomeVFSURI *uri = (GnomeVFSURI *) it->data;
-
-		if (!get_uri_info (uri, info))
+	for (it = file_list; it != NULL; it = it->next) {
+		GFile *file = (GFile *) it->data;
+		
+		file_info = g_file_query_info (file,
+					       G_FILE_ATTRIBUTE_STANDARD_TYPE,
+					       0, NULL, NULL);
+		if (file_info == NULL) {
 			continue;
+		}
+		file_type = g_file_info_get_file_type (file_info);
+		g_object_unref (file_info);
 			
-		if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
-			eog_list_store_append_directory (store, uri, info);
-		} else if (info->type == GNOME_VFS_FILE_TYPE_REGULAR && 
-			   g_list_length (uri_list) == 1) {
+		if (file_type == G_FILE_TYPE_DIRECTORY) {
+			eog_list_store_append_directory (store, file, file_type);
+		} else if (file_type == G_FILE_TYPE_REGULAR && 
+			   g_list_length (file_list) == 1) {
 
-			initial_uri = gnome_vfs_uri_dup (uri); 
+			initial_file = g_file_dup (file);
 
-			uri = gnome_vfs_uri_get_parent (uri);
-			
-			if (!get_uri_info (uri, info))
-				continue;
+			file = g_file_get_parent (file);
+			file_info = g_file_query_info (file,
+						       G_FILE_ATTRIBUTE_STANDARD_TYPE,
+						       0, NULL, NULL);
+			file_type = g_file_info_get_file_type (file_info);
+			g_object_unref (file_info);
 
-			if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
-				eog_list_store_append_directory (store, uri, info);
+			if (file_type == G_FILE_TYPE_DIRECTORY) {
+				eog_list_store_append_directory (store, file, file_type);
 
-				if (!is_file_in_list_store_uri (store,
-								initial_uri, 
-								&iter)) {
-					eog_list_store_append_image_from_uri (store, initial_uri, TRUE);
+				if (!is_file_in_list_store_file (store,
+								 initial_file, 
+								 &iter)) {
+					eog_list_store_append_image_from_file (store, initial_file);
 				}
 			} else {
-				eog_list_store_append_image_from_uri (store, initial_uri, FALSE);
+				eog_list_store_append_image_from_file (store, initial_file);
 			}
-		} else if (info->type == GNOME_VFS_FILE_TYPE_REGULAR && 
-			   g_list_length (uri_list) > 1) {
-			eog_list_store_append_image_from_uri (store, uri, FALSE);
+			g_object_unref (file);
+		} else if (file_type == G_FILE_TYPE_REGULAR && 
+			   g_list_length (file_list) > 1) {
+			eog_list_store_append_image_from_file (store, file);
 		}
 	}
 
-	gnome_vfs_file_info_unref (info);
-
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
 					      GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, 
 					      GTK_SORT_ASCENDING);
 	
-	if (initial_uri && 
-	    is_file_in_list_store_uri (store, initial_uri, &iter)) {
+	if (initial_file && 
+	    is_file_in_list_store_file (store, initial_file, &iter)) {
 		store->priv->initial_image = eog_list_store_get_pos_by_iter (store, &iter);
-		gnome_vfs_uri_unref (initial_uri);
+		g_object_unref (initial_file);
 	} else {
 		store->priv->initial_image = 0;
 	} 
 }
 
+/**
+ * eog_list_store_remove_image:
+ * @store: An #EogListStore.
+ * @image: An #EogImage.
+ *
+ * Removes @image from @store.
+ **/
 void
 eog_list_store_remove_image (EogListStore *store, EogImage *image)
 {
 	GtkTreeIter iter;
-	GnomeVFSURI *uri;
+	GFile *file;
 
 	g_return_if_fail (EOG_IS_LIST_STORE (store));
 	g_return_if_fail (EOG_IS_IMAGE (image));
 
-	uri = eog_image_get_uri (image);
+	file = eog_image_get_file (image);
 
-	if (is_file_in_list_store_uri (store, uri, &iter)) {
+	if (is_file_in_list_store_file (store, file, &iter)) {
 		eog_list_store_remove (store, &iter);
 	}
-	gnome_vfs_uri_unref (uri);
+	g_object_unref (file);
 }
 
+/**
+ * eog_list_store_new_from_glist:
+ * @list: a %NULL-terminated list of #EogImage's.
+ *
+ * Creates a new #EogListStore from a list of #EogImage's.
+ * The given list must be %NULL-terminated.
+ *
+ * Returns: a new #EogListStore.
+ **/
 GtkListStore *
 eog_list_store_new_from_glist (GList *list)
 {
@@ -639,26 +664,47 @@ eog_list_store_new_from_glist (GList *list)
 	return store;
 }
 
+/**
+ * eog_list_store_get_pos_by_image:
+ * @store: An #EogListStore.
+ * @image: An #EogImage.
+ *
+ * Gets the position where @image is stored in @store. If @image
+ * is not stored in @store, -1 is returned.
+ *
+ * Returns: the position of @image in @store or -1 if not found.
+ **/
 gint
 eog_list_store_get_pos_by_image (EogListStore *store, EogImage *image)
 {
 	GtkTreeIter iter;
 	gint pos = -1;
-	GnomeVFSURI *uri;
+	GFile *file;
 
 	g_return_val_if_fail (EOG_IS_LIST_STORE (store), -1);
 	g_return_val_if_fail (EOG_IS_IMAGE (image), -1);
 	
-	uri = eog_image_get_uri (image);
+	file = eog_image_get_file (image);
 
-	if (is_file_in_list_store_uri (store, uri, &iter)) {
+	if (is_file_in_list_store_file (store, file, &iter)) {
 		pos = eog_list_store_get_pos_by_iter (store, &iter);
 	}
 
-	gnome_vfs_uri_unref (uri);
+	g_object_unref (file);
 	return pos;
 }
 
+/**
+ * eog_list_store_get_image_by_pos:
+ * @store: An #EogListStore.
+ * @pos: the position of the required #EogImage.
+ *
+ * Gets the #EogImage in the position @pos of @store. If there is
+ * no image at position @pos, %NULL is returned.
+ *
+ * Returns: the #EogImage in position @pos or %NULL.
+ *
+ **/
 EogImage *
 eog_list_store_get_image_by_pos (EogListStore *store, const gint pos)
 {
@@ -676,6 +722,15 @@ eog_list_store_get_image_by_pos (EogListStore *store, const gint pos)
 	return image;
 }
 
+/**
+ * eog_list_store_get_pos_by_iter:
+ * @store: An #EogListStore.
+ * @iter: A #GtkTreeIter pointing to an image in @store.
+ *
+ * Gets the position of the image pointed by @iter.
+ *
+ * Returns: The position of the image pointed by @iter.
+ **/
 gint
 eog_list_store_get_pos_by_iter (EogListStore *store, 
 				GtkTreeIter *iter)
@@ -692,6 +747,14 @@ eog_list_store_get_pos_by_iter (EogListStore *store,
 	return pos;
 }
 
+/**
+ * eog_list_store_length:
+ * @store: An #EogListStore.
+ *
+ * Returns the number of images in the store.
+ *
+ * Returns: The number of images in @store.
+ **/
 gint
 eog_list_store_length (EogListStore *store)
 {
@@ -700,6 +763,16 @@ eog_list_store_length (EogListStore *store)
 	return gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL);
 }
 
+/**
+ * eog_list_store_get_initial_pos:
+ * @store: An #EogListStore.
+ *
+ * Gets the position of the #EogImage that should be loaded first.
+ * If not set, it returns -1.
+ *
+ * Returns: the position of the image to be loaded first or -1.
+ *
+ **/
 gint
 eog_list_store_get_initial_pos (EogListStore *store)
 {
@@ -763,6 +836,14 @@ eog_list_store_add_thumbnail_job (EogListStore *store, GtkTreeIter *iter)
 	g_object_unref (image);
 }
 
+/**
+ * eog_list_store_thumbnail_set:
+ * @store: An #EogListStore.
+ * @iter: A #GtkTreeIter pointing to an image in @store.
+ *
+ * Sets the thumbnail for the image pointed by @iter.
+ *
+ **/
 void
 eog_list_store_thumbnail_set (EogListStore *store, 
 			      GtkTreeIter *iter)
@@ -780,6 +861,15 @@ eog_list_store_thumbnail_set (EogListStore *store,
 	eog_list_store_add_thumbnail_job (store, iter);
 }
 
+/**
+ * eog_list_store_thumbnail_unset:
+ * @store: An #EogListStore.
+ * @iter: A #GtkTreeIter pointing to an image in @store.
+ *
+ * Unsets the thumbnail for the image pointed by @iter, changing
+ * it to a "busy" icon.
+ *
+ **/
 void
 eog_list_store_thumbnail_unset (EogListStore *store, 
 				GtkTreeIter *iter)
@@ -800,6 +890,14 @@ eog_list_store_thumbnail_unset (EogListStore *store,
 			    -1);
 }
 
+/**
+ * eog_list_store_thumbnail_refresh:
+ * @store: An #EogListStore.
+ * @iter: A #GtkTreeIter pointing to an image in @store.
+ *
+ * Refreshes the thumbnail for the image pointed by @iter.
+ *
+ **/
 void
 eog_list_store_thumbnail_refresh (EogListStore *store,
 				  GtkTreeIter *iter)
